@@ -12,7 +12,7 @@ import treelib  # type: ignore
 import yaml
 
 import liitos.gather as gat
-from liitos import ENCODING, log
+from liitos import ENCODING, LOG_SEPARATOR, log
 
 ALT_INJECTOR_HACK = 'INJECTED-ALT-TEXT-TO-TRIGGER-FIGURE-ENVIRONMENT-AROUND-IMAGE-IN-PANDOC'
 CAP_INJECTOR_HACK = 'INJECTED-CAP-TEXT-TO-MARK-MISSING-CAPTION-IN-OUTPUT'
@@ -372,8 +372,8 @@ def concatenate(
     doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool | str]
 ) -> int:
     """Later alligator."""
-    separator = '- ' * 80
-    log.info(separator)
+    log.info(LOG_SEPARATOR)
+    log.info('entered concat function ...')
     target_code = target_key
     facet_code = facet_key
     if not facet_code.strip() or not target_code.strip():
@@ -458,7 +458,7 @@ def concatenate(
         documents = {}
         insert_regions = {}
         img_collector = []
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info('processing binder ...')
         for entry in binder:
             path = DOC_BASE / entry
@@ -647,21 +647,21 @@ def concatenate(
 
         top_down_paths = tree.paths_to_leaves()
         bottom_up_paths = [list(reversed(td_p)) for td_p in top_down_paths]
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info('resulting tree:')
         with RedirectedStdout() as out:
             tree.show()
             for row in str(out).rstrip('\n').split('\n'):
                 log.info(row)
 
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info(f'provisioning chains for the {len(bottom_up_paths)} bottom up leaf paths:')
         for num, leaf_path in enumerate(bottom_up_paths):
             the_way_up = f'|-> {leaf_path[0]}' if len(leaf_path) == 1 else f'{" -> ".join(leaf_path)}'
             log.info(f'{num :2d}: {the_way_up}')
 
         concat = {}
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info(f'dependencies for the {len(insert_regions)} document parts:')
         for key, regions in insert_regions.items():
             num_in = len(regions)
@@ -678,25 +678,25 @@ def concatenate(
                 log.info(f'  * did concat {key} document for insertion')
 
         chains = [leaf_path for leaf_path in bottom_up_paths]
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info(f'starting insertions bottom up for the {len(chains)} inclusion chains:')
         todo = [[job for job in chain if job not in concat] for chain in chains]
         while todo != [[]]:
             todo = rollup(todo, documents, insert_regions, concat)
 
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info('writing final concat markdown to document.md')
         with open('document.md', 'wt', encoding=ENCODING) as handle:
             handle.write('\n'.join(concat[bind] for bind in binder) + '\n')
 
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info('collecting assets (images and diagrams)')
         collect_assets(img_collector)
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info(f'concat result document (document.md) and artifacts are within folder ({os.getcwd()}/)')
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         log.info('processing complete - SUCCESS')
-        log.info(separator)
+        log.info(LOG_SEPARATOR)
         return 0
 
     log.error(f'structure data files with other than one target currently not supported - found targets ({targets})')
